@@ -44,14 +44,14 @@ DataBackendCbind = R6Class("DataBackendCbind", inherit = DataBackend, cloneable
       d2 = private$.data$b2$distinct(rows, cols, na_rm = na_rm)
       d1 = private$.data$b1$distinct(rows, setdiff(cols, names(d2)), na_rm = na_rm)
       res = c(d1, d2)
-      res[match(cols, names(res), nomatch = 0L)]
+      res[reorder_vector(names(res), cols)]
     },
 
     missings = function(rows, cols) {
       m2 = private$.data$b2$missings(rows, cols)
       m1 = private$.data$b1$missings(rows, setdiff(cols, names(m2)))
       res = c(m1, m2)
-      res[match(cols, names(res), nomatch = 0L)]
+      res[reorder_vector(names(res), cols)]
     }
   ),
 
@@ -76,7 +76,7 @@ DataBackendCbind = R6Class("DataBackendCbind", inherit = DataBackend, cloneable
   private = list(
     .calculate_hash = function() {
       data = private$.data
-      hash(data$b1$hash, data$b2$hash)
+      calculate_hash(data$b1$hash, data$b2$hash)
     }
   )
 )
