@@ -17,12 +17,13 @@
 #'    \item{segfault_train:}{Probability to provokes a segfault during train.}
 #'    \item{segfault_predict:}{Probability to provokes a segfault during predict.}
 #'    \item{predict_missing}{Ratio of predictions which will be NA.}
+#'    \item{predict_missing_type}{To to encode missingness. \dQuote{na} will insert NA values, \dQuote{omit} will just return fewer predictions than requested.}
 #'    \item{save_tasks:}{Saves input task in `model` slot during training and prediction.}
 #'    \item{threads:}{Number of threads to use. Has no effect.}
 #'    \item{x:}{Numeric tuning parameter. Has no effect.}
 #' }
 #' Note that segfaults may not be triggered on your operating system.
-#' Also note that if they work, they will tear down your R session immediately!
+#' Also note that if they work as intended, they will tear down your R session immediately!
 #'
 #' @templateVar id classif.featureless
 #' @template section_dictionary_learner
@@ -55,21 +56,20 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
         id = "classif.debug",
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
         predict_types = c("response", "prob"),
-        param_set = ParamSet$new(
-          params = list(
-            ParamDbl$new("message_train", lower = 0, upper = 1, default = 0, tags = "train"),
-            ParamDbl$new("message_predict", lower = 0, upper = 1, default = 0, tags = "predict"),
-            ParamDbl$new("warning_train", lower = 0, upper = 1, default = 0, tags = "train"),
-            ParamDbl$new("warning_predict", lower = 0, upper = 1, default = 0, tags = "predict"),
-            ParamDbl$new("error_train", lower = 0, upper = 1, default = 0, tags = "train"),
-            ParamDbl$new("error_predict", lower = 0, upper = 1, default = 0, tags = "predict"),
-            ParamDbl$new("segfault_train", lower = 0, upper = 1, default = 0, tags = "train"),
-            ParamDbl$new("segfault_predict", lower = 0, upper = 1, default = 0, tags = "predict"),
-            ParamDbl$new("predict_missing", lower = 0, upper = 1, default = 0, tags = "predict"),
-            ParamLgl$new("save_tasks", default = FALSE, tags = c("train", "predict")),
-            ParamInt$new("threads", lower = 1, tags = c("train", "threads")),
-            ParamDbl$new("x", lower = 0, upper = 1, tags = "train")
-          )
+        param_set = ps(
+          error_predict        = p_dbl(0, 1, default = 0, tags = "predict"),
+          error_train          = p_dbl(0, 1, default = 0, tags = "train"),
+          message_predict      = p_dbl(0, 1, default = 0, tags = "predict"),
+          message_train        = p_dbl(0, 1, default = 0, tags = "train"),
+          predict_missing      = p_dbl(0, 1, default = 0, tags = "predict"),
+          predict_missing_type = p_fct(c("na", "omit"), default = "na", tags = "predict"),
+          save_tasks           = p_lgl(default = FALSE, tags = c("train", "predict")),
+          segfault_predict     = p_dbl(0, 1, default = 0, tags = "predict"),
+          segfault_train       = p_dbl(0, 1, default = 0, tags = "train"),
+          threads              = p_int(1L, tags = c("train", "threads")),
+          warning_predict      = p_dbl(0, 1, default = 0, tags = "predict"),
+          warning_train        = p_dbl(0, 1, default = 0, tags = "train"),
+          x                    = p_dbl(0, 1, tags = "train")
         ),
         properties = c("twoclass", "multiclass", "missings"),
         man = "mlr3::mlr_learners_classif.debug",
@@ -130,12 +130,16 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
       }
 
       response = prob = NULL
+      missing_type = pv$predict_missing_type %??% "na"
 
       if ("response" %in% self$predict_type) {
         response = rep.int(unclass(self$model$response), n)
         if (!is.null(pv$predict_missing)) {
           ii = sample.int(n, n * pv$predict_missing)
-          response = replace(response, ii, NA)
+          response = switch(missing_type,
+            "na" = replace(response, ii, NA),
+            "omit" = response[ii]
+          )
         }
       }
 
@@ -147,7 +151,15 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
 
         if (!is.null(pv$predict_missing)) {
           ii = sample.int(n, n * pv$predict_missing)
-          prob[ii, 1L] = NA_real_
+          prob = switch(missing_type,
+            "na" = {
+              prob[ii, ] = NA_real_
+              prob
+            },
+            "omit" = {
+              prob[ii, , drop = FALSE]
+            }
+          )
         }
       }
 
