@@ -5,13 +5,19 @@
 #'
 #' @description
 #' Measures the number of selected features by extracting it from learners with property `"selected_features"`.
-#' If the learner does not support this, `NA` is returned.
+#' If parameter `normalize` is set to `TRUE`, the relative number of features instead of the absolute
+#' number of features is returned.
+#' Note that the models must be stored to be able to extract this information.
+#' If the learner does not support the extraction of used features, `NA` is returned.
 #'
 #' This measure requires the [Task] and the [Learner] for scoring.
 #'
 #' @templateVar id selected_features
 #' @template section_dictionary_measure
 #'
+#' @section Parameters:
+#' `r rd_info(msr("classif.costs")$param_set)`
+#'
 #'
 #' @section Meta Information:
 #' * Type: `NA`
@@ -21,21 +27,25 @@
 #'
 #' @template seealso_measure
 #' @export
+#' @examples
+#' task = tsk("german_credit")
+#' learner = lrn("classif.rpart")
+#' rr = resample(task, learner, rsmp("cv", folds = 3), store_models = TRUE)
+#'
+#' scores = rr$score(msr("selected_features"))
+#' scores[, c("iteration", "selected_features")]
 MeasureSelectedFeatures = R6Class("MeasureSelectedFeatures",
   inherit = Measure,
   public = list(
-    #' @field normalize (`logical(1)`)\cr
-    #' If set to `TRUE`, divides the number of features by the total number of features.
-    normalize = NULL,
-
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
-    #'
-    #' @param normalize (`logical(1)`)\cr
-    #'   If set to `TRUE`, divides the number of features by the total number of features.
-    initialize = function(normalize = FALSE) {
+    initialize = function() {
+      param_set = ps(normalize = p_lgl(default = FALSE, tags = "required"))
+      param_set$values = list(normalize = FALSE)
+
       super$initialize(
         id = "selected_features",
+        param_set = param_set,
         task_type = NA_character_,
         properties = c("requires_task", "requires_learner", "requires_model"),
         predict_type = "response",
@@ -43,20 +53,22 @@ MeasureSelectedFeatures = R6Class("MeasureSelectedFeatures",
         minimize = TRUE,
         man = "mlr3::mlr_measures_selected_features"
       )
-      self$normalize = assert_flag(normalize)
     }
   ),
 
   private = list(
     .score = function(prediction, task, learner, ...) {
+      learner = learner$base_learner()
       if ("selected_features" %nin% learner$properties) {
         return(NA_integer_)
       }
+
       n = length(learner$selected_features())
-      if (self$normalize) {
+      if (self$param_set$get_values()$normalize) {
         n = n / length(task$feature_names)
       }
-      n
+
+      return(n)
     }
   )
 )
