@@ -7,19 +7,33 @@ check_prediction_data.PredictionDataClassif = function(pdata) { # nolint
   lvls = levels(pdata$truth)
 
   if (!is.null(pdata$response)) {
-    pdata$response = assert_factor(as_factor(pdata$response, levels = lvls), len = n)
+    pdata$response = assert_factor(as_factor(pdata$response, levels = lvls))
+    assert_prediction_count(length(pdata$response), n, "response")
   }
 
   if (!is.null(pdata$prob)) {
-    prob = assert_matrix(pdata$prob, nrows = n, ncols = length(lvls))
+    prob = assert_matrix(pdata$prob)
+    assert_prediction_count(nrow(pdata$prob), n, "prob")
     assert_numeric(prob, lower = 0, upper = 1)
+    assert_row_sums(prob)
+
     if (!identical(colnames(prob), lvls)) {
-      assert_names(colnames(prob), permutation.of = lvls)
-      prob = prob[, match(colnames(prob), lvls), drop = FALSE]
+      assert_subset(colnames(prob), lvls)
+
+      # add missing columns with prob == 0
+      miss = setdiff(lvls, colnames(prob))
+      if (length(miss)) {
+        prob = cbind(prob, matrix(0, nrow = n, ncol = length(miss), dimnames = list(NULL, miss)))
+      }
+
+      # reorder columns to match the level order of `truth`
+      prob = prob[, reorder_vector(colnames(prob), lvls), drop = FALSE]
     }
+
     if (!is.null(rownames(prob))) {
       rownames(prob) = NULL
     }
+
     pdata$prob = prob
 
     if (is.null(pdata$response)) {
@@ -76,7 +90,7 @@ c.PredictionDataClassif = function(..., keep_duplicates = TRUE) {
   if (!keep_duplicates) {
     keep = !duplicated(tab, by = "row_ids", fromLast = TRUE)
     tab = tab[keep]
-    prob = prob[keep,, drop = FALSE]
+    prob = prob[keep, , drop = FALSE]
   }
 
   result = as.list(tab)
