@@ -4,8 +4,15 @@ check_prediction_data.PredictionDataRegr = function(pdata) { # nolint
   pdata$row_ids = assert_row_ids(pdata$row_ids)
   n = length(pdata$row_ids)
 
-  assert_numeric(pdata$response, len = n, any.missing = FALSE, null.ok = TRUE)
-  assert_numeric(pdata$se, len = n, lower = 0, any.missing = FALSE, null.ok = TRUE)
+  if (!is.null(pdata$response)) {
+    assert_numeric(pdata$response, any.missing = FALSE)
+    assert_prediction_count(length(pdata$response), n, "response")
+  }
+
+  if (!is.null(pdata$se)) {
+    assert_numeric(pdata$se, lower = 0, any.missing = FALSE)
+    assert_prediction_count(length(pdata$se), n, "se")
+  }
 
   if (!is.null(pdata$distr)) {
     assert_class(pdata$distr, "VectorDistribution")
