@@ -45,7 +45,6 @@
 #' The sets can be accessed via `$train_set(i)` and `$test_set(i)`, respectively.
 #'
 #'
-#' @family Resampling
 #' @template seealso_resampling
 #' @export
 #' @examples
@@ -121,7 +120,7 @@ Resampling = R6Class("Resampling",
     #'   Set to `TRUE` if this resampling strategy may have duplicated row ids in a single training set or test set.
     #'
     #' Note that this object is typically constructed via a derived classes, e.g. [ResamplingCV] or [ResamplingHoldout].
-    initialize = function(id, param_set = ParamSet$new(), duplicated_ids = FALSE, man = NA_character_) {
+    initialize = function(id, param_set = ps(), duplicated_ids = FALSE, man = NA_character_) {
       self$id = assert_string(id, min.chars = 1L)
       self$param_set = assert_param_set(param_set)
       self$duplicated_ids = assert_flag(duplicated_ids)
@@ -218,7 +217,10 @@ Resampling = R6Class("Resampling",
     #' @template field_hash
     hash = function(rhs) {
       assert_ro_binding(rhs)
-      hash(list(class(self), self$id, self$param_set$values, self$instance))
+      if (!self$is_instantiated) {
+        return(NA_character_)
+      }
+      calculate_hash(list(class(self), self$id, self$param_set$values, self$instance))
     }
   ),
 
