@@ -295,18 +295,20 @@ ResultData = R6Class("ResultData",
     #'   Returns `NULL` if the [ResultData] is empty.
     task_type = function() {
       tab = self$data$tasks
-      if (nrow(tab))
+      if (nrow(tab)) {
         tab$task[[1L]]$task_type
-      else
+      } else {
         NULL
+      }
     }
   ),
 
   private = list(
     get_view_index = function(view) {
-      if (is.null(view))
+      if (is.null(view)) {
         return(TRUE)
-       self$data$fact[list(view), on = "uhash", nomatch = NULL, which = TRUE]
+      }
+      self$data$fact[list(view), on = "uhash", nomatch = NULL, which = TRUE]
     },
 
     deep_clone = function(name, value) {
@@ -382,8 +384,8 @@ reassemble_learners = function(learners, states = NULL, param_vals = NULL) {
   learners = lapply(learners, function(l) l$clone(deep = TRUE))
 
   if (!is.null(states)) {
-     Map(function(l, s) {
-       l$state = s
+    Map(function(l, s) {
+      l$state = s
     }, l = learners, s = states)
   }
 
