@@ -24,9 +24,9 @@ TaskGeneratorCircle = R6Class("TaskGeneratorCircle",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      ps = ParamSet$new(list(
-        ParamInt$new("d", lower = 2L, default = 2L)
-      ))
+      ps = ps(
+        d = p_int(2L, default = 2L)
+      )
 
       super$initialize(id = "circle", "classif", "mlbench", ps, man = "mlr3::mlr_task_generators_circle")
     },
@@ -58,4 +58,3 @@ TaskGeneratorCircle = R6Class("TaskGeneratorCircle",
 
 #' @include mlr_task_generators.R
 mlr_task_generators$add("circle", TaskGeneratorCircle)
-
