@@ -23,10 +23,10 @@ TaskGeneratorSpirals = R6Class("TaskGeneratorSpirals",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      ps = ParamSet$new(list(
-        ParamInt$new("cycles", lower = 1L, default = 1L),
-        ParamDbl$new("sd", lower = 0, default = 0)
-      ))
+      ps = ps(
+        cycles = p_int(1L, default = 1L),
+        sd     = p_dbl(0, default = 0)
+      )
 
       super$initialize(id = "spirals", "classif", "mlbench", ps, man = "mlr3::mlr_task_generators_spirals")
     },
