@@ -87,7 +87,7 @@ local({
     "use", "validation"
   )
 
-  tmp = c("feature", "target", "name", "order", "stratum", "group", "weight", "uri")
+  tmp = c("feature", "target", "name", "order", "stratum", "group", "weight")
   mlr_reflections$task_col_roles = list(
     regr = tmp,
     classif = tmp
@@ -100,7 +100,7 @@ local({
   )
 
   ### Learner
-  tmp = c("featureless", "missings", "weights", "importance", "selected_features", "oob_error")
+  tmp = c("featureless", "missings", "weights", "importance", "selected_features", "oob_error", "loglik")
   mlr_reflections$learner_properties = list(
     classif = c(tmp, "twoclass", "multiclass"),
     regr = tmp
