@@ -81,9 +81,9 @@ test_that("bmr$combine()", {
     expect_benchmark_result(bmr_new)
     expect_benchmark_result(bmr_combined)
 
-    expect_data_table(bmr$data$data$fact, nrows = 18L)
-    expect_data_table(bmr_new$data$data$fact, nrows = 6L)
-    expect_data_table(bmr_combined$data$data$fact, nrows = 24L)
+    expect_data_table(get_private(bmr)$.data$data$fact, nrows = 18L)
+    expect_data_table(private(bmr_new)$.data$data$fact, nrows = 6L)
+    expect_data_table(private(bmr_combined)$.data$data$fact, nrows = 24L)
 
     expect_false("pima" %in% bmr$tasks$task_id)
     expect_true("pima" %in% bmr_new$tasks$task_id)
@@ -93,7 +93,7 @@ test_that("bmr$combine()", {
   rr = resample(tsk("zoo"), lrn("classif.rpart"), rsmp("holdout"))
   bmr2 = c(combined[[1]], rr)
   expect_benchmark_result(bmr2)
-  expect_data_table(bmr2$data$data$fact, nrows = 25L)
+  expect_data_table(private(bmr2)$.data$data$fact, nrows = 25L)
 })
 
 test_that("empty bmr", {
@@ -105,7 +105,7 @@ test_that("empty bmr", {
 
   bmr_new$combine(bmr)
   expect_benchmark_result(bmr_new)
-  expect_data_table(bmr_new$data$data$fact, nrows = nrow(bmr$data))
+  expect_data_table(private(bmr_new)$.data$data$fact, nrows = nrow(get_private(bmr)$.data))
 })
 
 test_that("bmr$resample_result()", {
@@ -128,7 +128,7 @@ test_that("inputs are cloned", {
   rr = bmr$resample_result(1)
 
   expect_different_address(task, rr$task)
-  expect_different_address(learner, rr$data$data$learner_components$learner[[1L]])
+  expect_different_address(learner, private(rr)$.data$data$learner_components$learner[[1L]])
   expect_different_address(resampling, rr$resampling)
 })
 
@@ -234,37 +234,23 @@ test_that("filter", {
   design = benchmark_grid(tasks, learners, resamplings)
   bmr = benchmark(design)
 
-  expect_data_table(bmr$data$data$fact, nrows = 16)
+  expect_data_table(get_private(bmr)$.data$data$fact, nrows = 16)
 
   bmr$filter(task_ids = "sonar")
-  expect_data_table(bmr$data$data$fact, nrows = 8)
-  expect_resultdata(bmr$data, TRUE)
+  expect_data_table(get_private(bmr)$.data$data$fact, nrows = 8)
+  expect_resultdata(get_private(bmr)$.data, TRUE)
 
   bmr$filter(learner_ids = "classif.rpart")
-  expect_data_table(bmr$data$data$fact, nrows = 4)
-  expect_resultdata(bmr$data, TRUE)
+  expect_data_table(get_private(bmr)$.data$data$fact, nrows = 4)
+  expect_resultdata(get_private(bmr)$.data, TRUE)
 
   bmr$filter(resampling_ids = "cv")
-  expect_data_table(bmr$data$data$fact, nrows = 3)
-  expect_resultdata(bmr$data, TRUE)
+  expect_data_table(get_private(bmr)$.data$data$fact, nrows = 3)
+  expect_resultdata(get_private(bmr)$.data, TRUE)
 
   expect_benchmark_result(bmr)
 })
 
-test_that("parallelization works", {
-  skip_on_os("windows") # currently buggy
-
-  grid = benchmark_grid(list(tsk("wine"), tsk("sonar")), replicate(2, lrn("classif.debug")), rsmp("cv", folds = 2))
-  njobs = 3L
-  bmr = with_future(future::multisession,  {
-    benchmark(grid, store_models = TRUE)
-  }, workers = njobs)
-
-  expect_benchmark_result(bmr)
-  pids = map_int(as.data.table(bmr)$learner, function(x) x$model$pid)
-  expect_equal(length(unique(pids)), njobs)
-})
-
 test_that("aggregated performance values are calculated correctly (#555)", {
   task = tsk("spam")
   learner1 = lrn("classif.featureless")
@@ -301,3 +287,20 @@ test_that("debug branch", {
   bmr = invoke(benchmark, design, .opts = list(mlr3.debug = TRUE))
   expect_benchmark_result(bmr)
 })
+
+test_that("encapsulatiion", {
+  learners = list(lrn("classif.debug", error_train = 1), lrn("classif.rpart"))
+  grid = benchmark_grid(tasks, learners, resamplings)
+
+  expect_error(benchmark(grid), "classif.debug->train()")
+  bmr = benchmark(grid, encapsulate = "evaluate")
+  aggr = bmr$aggregate(conditions = TRUE)
+  expect_true(all(aggr[learner_id == "classif.debug", errors] == 3L))
+  expect_true(all(aggr[learner_id != "classif.debug", errors] == 0L))
+
+  for (learner in bmr$learners$learner) {
+    expect_class(learner$fallback, "LearnerClassifFeatureless")
+    expect_equal(learner$encapsulate[["train"]], "evaluate")
+    expect_equal(learner$encapsulate[["predict"]], "evaluate")
+  }
+})
