@@ -8,12 +8,14 @@ test_that("convert_task - Regr -> Regr", {
   expect_true(all(result$feature_names != "age"))
   expect_true(all(result$feature_names != "medv"))
   expect_true(all(unlist(imap(result$row_roles,
-          .f = function(z, x) {all(result$row_roles[[x]] == task$row_roles[[x]])}))
-      ))
+    .f = function(z, x) {
+      all(result$row_roles[[x]] == task$row_roles[[x]])
+    }
+  ))))
   expect_true(
     all(map_lgl(c("weights", "groups", "strata", "nrow"), function(x) {
-        all(result[[x]] == task[[x]])
-  })))
+      all(result[[x]] == task[[x]])
+    })))
 })
 
 test_that("convert_task - Regr -> Classif", {
@@ -26,12 +28,14 @@ test_that("convert_task - Regr -> Classif", {
   expect_true(all(result$feature_names != "chas"))
   expect_true(all(result$feature_names != "medv"))
   expect_true(all(unlist(imap(result$row_roles,
-    .f = function(z, x) {all(result$row_roles[[x]] == task$row_roles[[x]])}))
-  ))
+    .f = function(z, x) {
+      all(result$row_roles[[x]] == task$row_roles[[x]])
+    }
+  ))))
   expect_true(
     all(map_lgl(c("weights", "groups", "strata", "nrow"), function(x) {
       all(result[[x]] == task[[x]])
-  })))
+    })))
 })
 
 test_that("convert_task - Classif -> Regr", {
@@ -44,12 +48,14 @@ test_that("convert_task - Classif -> Regr", {
   expect_true(all(result$feature_names != "Sepal.Width"))
   expect_true(all(result$feature_names != "Species"))
   expect_true(all(unlist(imap(result$row_roles,
-    .f = function(z, x) {all(result$row_roles[[x]] == task$row_roles[[x]])}))
-  ))
+    .f = function(z, x) {
+      all(result$row_roles[[x]] == task$row_roles[[x]])
+    }
+  ))))
   expect_true(
     all(map_lgl(c("weights", "groups", "strata", "nrow"), function(x) {
       all(result[[x]] == task[[x]])
-  })))
+    })))
 })
 
 test_that("convert_task - same target", {
@@ -66,13 +72,17 @@ test_that("convert_task - same target", {
     expect_task(result)
     expect_true(result$col_roles$target == "medv")
     expect_true(all(unlist(imap(result$row_roles,
-      .f = function(z, x) {all(result$row_roles[[x]] == task$row_roles[[x]])}))
-    ))
+      .f = function(z, x) {
+        all(result$row_roles[[x]] == task$row_roles[[x]])
+      }
+    ))))
     expect_true(
       all(map_lgl(
         c("weights", "groups", "strata", "nrow", "ncol", "feature_names", "target_names",
           "task_type"),
-        function(x) {all(result[[x]] == task[[x]])}
+        function(x) {
+          all(result[[x]] == task[[x]])
+        }
     )))
   }
 })
